@@ -39,10 +39,24 @@ apcluster.matrix <- function(s, x, p=NA, q=NA, maxits=1000, convits=100,
     # If argument p is not given, p is set to median of s
     if (any(is.na(p)))
     {
-        if (is.na(q))
-            p <- median(s[setdiff(which(s > -Inf), 0:(N - 1) * N + 1:N)])
+        if (is(s, "KernelMatrix"))
+        {
+            if (is.na(q))
+                p <- median(as.vector(s)[setdiff(which(s > -Inf),
+                                                 0:(N - 1) * N + 1:N)])
+            else
+                p <- quantile(as.vector(s)[setdiff(which(s > -Inf),
+                                                   0:(N - 1) * N + 1:N)], q)
+        }
         else
-            p <- quantile(s[setdiff(which(s > -Inf), 0:(N - 1) * N + 1:N)], q)
+        {
+            if (is.na(q))
+                p <- median(s[setdiff(which(s > -Inf),
+                                      0:(N - 1) * N + 1:N)])
+            else
+                p <- quantile(s[setdiff(which(s > -Inf),
+                                        0:(N - 1) * N + 1:N)], q)
+        }
     }
 
     apresultObj@l <- N
@@ -207,7 +221,7 @@ apcluster.function <- function(s, x, p=NA, q=NA, maxits=1000, convits=100,
 
     sim <- s(x=x, ...)
 
-    if (!is(sim, "mMatrix") || (nrow(sim) != N) || ncol(sim) != N)
+    if (!is(sim, "AnyMatrix") || (nrow(sim) != N) || ncol(sim) != N)
         stop("computation of similarity matrix failed")
 
     apres <- apcluster(s=sim, p=p, q=q, maxits=maxits, convits=convits, lam=lam,
@@ -390,7 +404,7 @@ apcluster.otherSparse <- function(s, x, ...)
 {
     s <- try(as(as(s, "TsparseMatrix"), "dgTMatrix"))
 
-    if (class(s) == "try-error")
+    if (is(s, "try-error"))
         stop("cannot cast 's' (class '", class(s), "') to class 'dgTMatrix'")
 
     apcluster.dgTMatrix(s=s, ...)
@@ -404,7 +418,7 @@ apcluster.otherDense <- function(s, x, ...)
 {
     s <- try(as(s, "matrix"))
 
-    if (class(s) == "try-error")
+    if (is(s, "try-error"))
         stop("cannot cast 's' (class '", class(s), "') to class 'matrix'")
 
     apcluster.matrix(s=s, ...)
